import json
import logging
import re
import sys
import os.path

import git

id_set = set()
logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)
handler = logging.StreamHandler(sys.stdout)
formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
handler.setFormatter(formatter)
logger.addHandler(handler)

repo = git.Repo(".")
url_regex = re.compile(r"skill_tree_(\w+)")


def load_json(p):
    with open(p, 'r') as f:
        try:
            return json.loads(f.read())
        except UnicodeDecodeError:
            logger.error(f"json 文件 [{p}] 编码错误，请确保它的内容为 utf-8 编码或基于 base64 的 ascii")
            sys.exit(1)


def dump_json(p, j, exist_ok=False, override=False):
    if os.path.exists(p):
        if exist_ok:
            if not override:
                return
        else:
            logger.error(f"{p} already exist")
            sys.exit(0)

    with open(p, 'w+', encoding="utf8") as f:
        f.write(json.dumps(j, indent=2, ensure_ascii=False))


def user_name():
    return repo.config_reader().get_value("user", "name")


def tree_name():
    url = repo.remote().url
    print(url)
    return url_regex.search(url).group(1)


def default_notebook():
    if tree_name() in ["java", "python", "c"]:
        return True
    else:
        return False
